pub trait Encode<T>: TransferFunction {
// Required method
fn encode(v: T) -> T;
}Expand description
Encode a value from linear light to a stored signal (OETF).
Implement for scalar F: Float to get a transfer function at any precision.
A blanket impl provides Encode<[F; N]> automatically for any Encode<F>.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.