Rec709

Struct Rec709 

pub struct Rec709;
Rec. ITU-R BT.709-6 transfer function.

Same primaries as sRGB with a different curve, using a slope of 4.5 and an effective gamma of approximately 2.222. Used for HD broadcast. Visually close to sRGB but not interchangeable in precision workflows.

Implementations

Source

impl Rec709

pub const ALPHA: f32 = 1.09929682680944

Gain applied in the power-law segment.

pub const POWER: f32 = 0.45

Encoding power exponent.

pub const LINEAR_SLOPE: f32 = 4.5

Slope of the linear toe.

pub const LINEAR_THRESHOLD: f32 = 0.018053968510807

Linear light value at which the curve transitions to the power-law segment.

pub const ENCODED_THRESHOLD: f32 = 0.081242858298635

Encoded signal value at which the curve transitions to the power-law segment.