Channel layout types for RGB, luma, and YCbCr color models.
Structs
- Abgr
- ABGR layout. A=0 B=1 G=2 R=3.
- Argb
- ARGB layout. A=0 R=1 G=2 B=3.
- Bgr
- BGR layout. B=0 G=1 R=2.
- Bgra
- BGRA layout. B=0 G=1 R=2 A=3.
- LumaA
- Two-channel luma+alpha layout, generic over AlphaState. Y=0 A=1.
- Rgb
- RGB layout. R=0 G=1 B=2.
- Rgba
- RGBA layout. R=0 G=1 B=2 A=3.
- Ycbcr
- YCbCr layout. Y=0 Cb=1 Cr=2.
- Ycrcb
- YCrCb layout. Y=0 Cr=1 Cb=2.
Traits
- Luma
Layout - Marks a layout as valid for use with a luma color model.
- YCbCr
Layout - Marks a layout as valid for use with a YCbCr color model.