Color model type definitions.
Structs
- Cmyk
- Device-dependent CMYK. The mapping to XYZ is defined by a runtime ICC
profile. Channels are always
[C, M, Y, K]in that order. - Device
Rgb - Device-dependent RGB. The mapping to XYZ is defined by a runtime ICC
profile. Layout defaults to
Rgba. - Grid380_
730_ 10nm - CIE 10 nm spectral grid, 380–730 nm (36 bands).
- Grid380_
780_ 5nm - CIE 5 nm spectral grid, 380–780 nm (81 bands).
- Grid380_
780_ 10nm - CIE 10 nm spectral grid, 380–780 nm (41 bands).
- Grid400_
700_ 10nm - CIE 10 nm spectral grid, 400–700 nm (31 bands).
- IsBispectral
- Spectral kind marker for bispectral (fluorescent) reflectance.
- IsRadiance
- Spectral kind marker for spectral radiance, unbounded above.
- IsReflectance
- Spectral kind marker for spectral reflectance in [0, 1].
- IsTransmittance
- Spectral kind marker for spectral transmittance in[0, 1].
- LCh
- CIE LCh*, the polar form of CIELab.
- Lab
- CIE 1976 Lab* color space under reference white W.
- Luma
- Luma derived from an RGB space with primaries P and transfer function TF.
- Luma
Alpha - Luma with an alpha channel. Alpha state defaults to
Straight. - Oklab
- Oklab perceptual color space by Björn Ottosson, 2020.
- Oklch
- Oklch, the polar form of Oklab.
- Rgb
- A color model formed by composing primaries P, transfer function TF, and channel layout L. Layout defaults to Rgba.
- Spectral
- A spectral color value on grid
Gencoding physical quantityK. - Xyz
- CIE XYZ tristimulus space normalized to Y = 1 under illuminant W.
- YCbCr
- YCbCr derived from an RGB space with primaries P and transfer function TF.
Traits
- Bispectral
- Blanket alias: any spectral space whose kind is
IsBispectral. - Color
Matching Functions - Color matching functions for a specific observer evaluated on a specific grid.
- Radiance
- Blanket alias: any spectral space whose kind is
IsRadiance. - Reflectance
- Blanket alias: any spectral space whose kind is
IsReflectance. - Spectral
Kind - Identifies the physical quantity encoded by a spectral color value.
- Spectral
Space - Implemented by any spectral model that declares a physical kind.
- Transmittance
- Blanket alias: any spectral space whose kind is
IsTransmittance. - Wavelength
Grid - A physical wavelength axis.
Type Aliases
- Spectral31
Radiance - Spectral radiance on the 31-band ICC grid (400–700 nm, 10 nm).
- Spectral31
Reflectance - Spectral reflectance on the 31-band ICC grid (400–700 nm, 10 nm).
- Spectral31
Transmittance - Spectral transmittance on the 31-band ICC grid (400–700 nm, 10 nm).
- Spectral36
Radiance - Spectral radiance on the 36-band Stam rendering grid (380–730 nm, 10 nm).
- Spectral36
Reflectance - Spectral reflectance on the 36-band Stam rendering grid (380–730 nm, 10 nm).
- Spectral36
Transmittance - Spectral transmittance on the 36-band Stam rendering grid (380–730 nm, 10 nm).
- Spectral41
Radiance - Spectral radiance on the 41-band full-visible grid (380–780 nm, 10 nm).
- Spectral41
Reflectance - Spectral reflectance on the 41-band full-visible grid (380–780 nm, 10 nm).
- Spectral41
Transmittance - Spectral transmittance on the 41-band full-visible grid (380–780 nm, 10 nm).
- Spectral81
Radiance - Spectral radiance on the 81-band CIE standard grid (380–780 nm, 5 nm).
- Spectral81
Reflectance - Spectral reflectance on the 81-band CIE standard grid (380–780 nm, 5 nm).
- Spectral81
Transmittance - Spectral transmittance on the 81-band CIE standard grid (380–780 nm, 5 nm).