pub trait ChannelMap<const N: usize>: 'static {
const INDICES: [usize; N];
}Expand description
Maps all N channels to their storage indices.
INDICES contains the storage position of each logical channel in logical order.
For RGB layouts the first three are R, G, B. For perceptual spaces with an
OFFSET the color channels begin at OFFSET and alpha occupies the remaining slot.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.