pub struct Rec709;Expand description
Rec. ITU-R BT.709-6 transfer function.
Same primaries as sRGB with a different curve, using a slope of 4.5 and an effective gamma of approximately 2.222. Used for HD broadcast. Visually close to sRGB but not interchangeable in precision workflows.
Implementations
Sourceimpl Rec709
impl Rec709
Sourcepub const LINEAR_SLOPE: f32 = 4.5
pub const LINEAR_SLOPE: f32 = 4.5
Slope of the linear toe.
Sourcepub const LINEAR_THRESHOLD: f32 = 0.018053968510807
pub const LINEAR_THRESHOLD: f32 = 0.018053968510807
Linear light value at which the curve transitions to the power-law segment.
Sourcepub const ENCODED_THRESHOLD: f32 = 0.081242858298635
pub const ENCODED_THRESHOLD: f32 = 0.081242858298635
Encoded signal value at which the curve transitions to the power-law segment.